@@ -1,12 +1,11 @@
-from pathlib import Path, PosixPath
-from typing import Dict
+from pathlib import Path
 
 from cognite.airworkflow.model.project import Project, ProjectInfo
-from cognite.airworkflow.util import env
+from cognite.airworkflow.util import env, repoconfighelpers
 
 # List of base constants
 working_path = env.get_env_value("PWD")
-ROOT_DIR = PosixPath(working_path)
+ROOT_DIR = Path(working_path)
 FUNCTIONS_PATH = ROOT_DIR / "functions"
 CUSTOMERS_FUNCTIONS_PATH = FUNCTIONS_PATH / "customers"
 AIR_INFRA_FUNCTIONS_PATH = FUNCTIONS_PATH / "air_infrastructure"
@@ -30,7 +29,10 @@ SCHEMAS_PATH = BASE_PATH / "schemas"
 DEPLOYMENT_SCHEMA_PATH = SCHEMAS_PATH / "deployment-schema.yaml"
 CONFIG_SCHEMA_PATH = SCHEMAS_PATH / "config-schema.yaml"
 
-# Tenant name to api key variables name
-PROJECT_TO_API_KEYS: Dict[Project, ProjectInfo] = {
-    Project.NAME: ProjectInfo(Project.NAME, "AIR_DEPLOY_API_KEY", "AIR_API_KEY"),
-}
+url_dict = repoconfighelpers.get_url_dict()
+if Project.NAME.value in url_dict:
+    PROJECT_TO_API_KEYS = {
+        Project.NAME: ProjectInfo(Project.NAME, "AIR_DEPLOY_API_KEY", "AIR_API_KEY", str(url_dict[Project.NAME.value]))
+    }
+else:
+    PROJECT_TO_API_KEYS = {Project.NAME: ProjectInfo(Project.NAME, "AIR_DEPLOY_API_KEY", "AIR_API_KEY")}
