@@ -78,11 +78,17 @@ class ModelAssetHierarchy:
             self._create_asset(AIR_ROOT_ID, "", name="AIR")
             update = True
         if (self.existing_hierarchy.shape[0] == 0) or (AIR_MODELS not in self.existing_hierarchy["name"].tolist()):
-            self._create_asset(AIR_MODELS, "All custom models are stored here.", parent_external_id=AIR_ROOT_ID)
+            self._create_asset(
+                AIR_MODELS,
+                "All custom models are stored here.",
+                parent_external_id=AIR_ROOT_ID,
+            )
             update = True
         if (self.existing_hierarchy.shape[0] == 0) or (AIR_INFRA not in self.existing_hierarchy["name"].tolist()):
             self._create_asset(
-                AIR_INFRA, "All AIR infrastructure models are stored here.", parent_external_id=AIR_ROOT_ID
+                AIR_INFRA,
+                "All AIR infrastructure models are stored here.",
+                parent_external_id=AIR_ROOT_ID,
             )
             update = True
         if update:
@@ -96,7 +102,13 @@ class ModelAssetHierarchy:
         return self.existing_hierarchy
 
     def _create_asset(
-        self, ext_id: str, desc: str, *, name: str = "", parent_external_id: str = None, meta: Dict = None,
+        self,
+        ext_id: str,
+        desc: str,
+        *,
+        name: str = "",
+        parent_external_id: str = None,
+        meta: Dict = None,
     ) -> None:
         self.client.assets.create(
             Asset(
